Crate kcode_rust_library_toolchain

Crate kcode_rust_library_toolchain 

Disposable validation and publication for managed Rust library source.

Structs

Error
A toolchain failure with complete process diagnostics.

Functions

check
Formats and validates a disposable copy through all six release stages.
publish
Revalidates and publishes the formatted disposable copy to crates.io.

Type Aliases

Result
Result type returned by this crate.